@@ -1,4 +1,3 @@
-import os
 import random
 import weakref
 
@@ -125,17 +124,6 @@ class SentinelConnectionPool(ConnectionPool):
             pass
         raise SlaveNotFoundError('No slave found for %r' % (self.service_name))
 
-    def _checkpid(self):
-        if self.pid != os.getpid():
-            self.disconnect()
-            self.reset()
-            self.__init__(self.service_name, self.sentinel_manager,
-                          is_master=self.is_master,
-                          check_connection=self.check_connection,
-                          connection_class=self.connection_class,
-                          max_connections=self.max_connections,
-                          **self.connection_kwargs)
-
 
 class Sentinel(object):
     """
@@ -147,7 +135,7 @@ class Sentinel(object):
     >>> master.set('foo', 'bar')
     >>> slave = sentinel.slave_for('mymaster', socket_timeout=0.1)
     >>> slave.get('foo')
-    'bar'
+    b'bar'
 
     ``sentinels`` is a list of sentinel nodes. Each node is represented by
     a pair (hostname, port).
